@@ -23,7 +23,7 @@
 
 # FFC modules.
 from ffc.log import error
-from ffc.cpp import format
+from ffc.quadrature.cpp import format
 
 # FFC quadrature modules.
 from .symbolics import CONST
